@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019, Brandon Nielsen
+# Copyright (c) 2020, Brandon Nielsen
 # All rights reserved.
 #
 # This software may be modified and distributed under the terms
@@ -10,6 +10,7 @@ from aniso8601 import compat
 from aniso8601.builders import TupleBuilder
 from aniso8601.builders.python import PythonTimeBuilder
 from aniso8601.date import parse_date
+from aniso8601.decimalfraction import find_separator, normalize
 from aniso8601.exceptions import ISOFormatError, NegativeDurationError
 from aniso8601.time import parse_time
 
@@ -20,6 +21,13 @@ def parse_duration(isodurationstr, builder=PythonTimeBuilder):
     #PnYnMnDTnHnMnS (or any reduced precision equivalent)
     #P<date>T<time>
 
+    if not isinstance(isodurationstr, str):
+        raise ValueError('Duration must be string.')
+
+    if len(isodurationstr) == 0:
+        raise ISOFormatError('"{0}" is not a valid ISO 8601 duration.'
+                .format(isodurationstr))
+
     if isodurationstr[0] != 'P':
         raise ISOFormatError('ISO 8601 duration must start with a P.')
 
@@ -46,15 +54,18 @@ def _parse_duration_prescribed(durationstr, builder):
                              'character.')
 
     #Make sure only the lowest order element has decimal precision
-    if durationstr.count('.') > 1:
-        raise ISOFormatError('ISO 8601 allows only lowest order element to '
+    separator_index = find_separator(durationstr)
+    if separator_index != -1:
+        remaining = durationstr[separator_index + 1:]
+        if find_separator(remaining) != -1:
+            raise ISOFormatError('ISO 8601 allows only lowest order element to '
                              'have a decimal fraction.')
-    elif durationstr.count('.') == 1:
+
         #There should only ever be 1 letter after a decimal if there is more
         #then one, the string is invalid
         lettercount = 0
 
-        for character in durationstr.split('.')[1]:
+        for character in remaining:
             if character.isalpha() is True:
                 lettercount += 1
 
@@ -214,11 +225,7 @@ def _parse_duration_element(durationstr, elementstr):
 
     durationstartindex += 1
 
-    if ',' in durationstr:
-        #Replace the comma with a 'full-stop'
-        durationstr = durationstr.replace(',', '.')
-
-    return durationstr[durationstartindex:durationendindex]
+    return normalize(durationstr[durationstartindex:durationendindex])
 
 def _has_any_component(durationstr, components):
     #Given a duration string, and a list of components, returns True
