@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2018, Brandon Nielsen
+# Copyright (c) 2020, Brandon Nielsen
 # All rights reserved.
 #
 # This software may be modified and distributed under the terms
@@ -12,9 +12,6 @@ class ISOFormatError(ValueError):
 class NegativeDurationError(ValueError):
     """Raised when a duration is negative."""
 
-class RelativeValueError(ValueError):
-    """Raised when an invalid value is given for calendar level accuracy."""
-
 class YearOutOfBoundsError(ValueError):
     """Raised when year exceeds limits."""
 
